# ARM Bus and Abstraction definitions

ARM makes IP-XACT 1.2 and 1.4 BusDefs and Abstraction Definitions available for download at: amba.com. At the time of this writing, the URL for accessing the download is http://www.amba.com/products/solutions/amba_spirit_spec.html. The resulting files should be placed at the three locations amba.com exists in this distribution

- ./BusDefs/1.4/amba.com
- ./Leon2_1.2/amba.com
- ./Leon2_1.4/amba.com

Last modified: Mon Mar 10 21:29:06 CET 2008